Запуск сервера — СпамоБорец: документация

### Navigation

- index
- next |
- previous |
- СпамоБорец: документация »
- Руководство пользователя »

# Запуск сервера

При запуске текущим каталогом должен быть корневой каталог проекта. Запуск осуществляется с помощью утилиты twistd (http://twistedmatrix.com/projects/core/documentation/man/twistd-man.html).

Самый простой запуск без режима демона (в консоли):

    twistd -n spamfighter

### Navigation

- index
- next |
- previous |
- СпамоБорец: документация »
- Руководство пользователя »